@@ -120,20 +120,26 @@ static	char	* group_name;
 
 static	int	Ycmp(char * pattern, char * string)
 {
-	char	p[255], s[255]; char	* c, *d; int i;
+	char	p[255], s[255]; char	* c, *d, *t; int i;
 	int	cc;
 
 	/* Copy / fold */
 
-	for (c=pattern,d=p,i=(sizeof(p)-2); *c && i > 0; c++,d++,i--) *d = * c; *d = 0;
-	for (c=string, d=s,i=(sizeof(s)-2); *c && i > 0; c++,d++,i--) *d = * c; *d = 0;
+	for (c=pattern,d=p,i=(sizeof(p)-2); *c && i > 0; c++,d++,i--)
+	  *d = tolower(*c);
+	*d = 0;
+
+	for (c=string, d=s,i=(sizeof(s)-2); *c && i > 0; c++,d++,i--) 
+	  *d = tolower(*c);
+	*d = 0;
+
 
 	/* Compare */
-
+	
 #ifndef	NO_FNMATCH
-	cc = fnmatch(pattern,string,0) != FNM_NOMATCH; /* 941223/TW */
+	cc = fnmatch(p, s, 0) != FNM_NOMATCH; /* 941223/TW */
 #else
-	cc = ematch(pattern,string) == 0;
+	cc = ematch(p, s) == 0;
 #endif
 #ifdef DEBUG
 	if (edebug)
